==> ldap-account-manager_4.7.1.orig.tar.bz2: ldap-account-manager-4.7.1/templates/lib/extra/ckeditor/plugins/link/lang/ro.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'ro', {
	acccessKey: 'Tasta de acces',
	advanced: 'Avansat',
	advisoryContentType: 'Tipul consultativ al titlului',
	advisoryTitle: 'Titlul consultativ',
	anchor: {
		toolbar: 'Inserează/Editează ancoră',
		menu: 'Proprietăţi ancoră',
		title: 'Proprietăţi ancoră',
		name: 'Numele ancorei',
		errorName: 'Vă rugăm scrieţi numele ancorei',
		remove: 'Elimină ancora'
	},
	anchorId: 'după Id-ul elementului',
	anchorName: 'după numele ancorei',
	charset: 'Setul de caractere al resursei legate',
	cssClasses: 'Clasele cu stilul paginii (CSS)',
	emailAddress: 'Adresă de e-mail',
	emailBody: 'Opțiuni Meniu Contextual',
	emailSubject: 'Subiectul mesajului',
	id: 'Id',
	info: 'Informaţii despre link (Legătură web)',
	langCode: 'Direcţia cuvintelor',
	langDir: 'Direcţia cuvintelor',
	langDirLTR: 'stânga-dreapta (LTR)',
	langDirRTL: 'dreapta-stânga (RTL)',
	menu: 'Editează Link',
	name: 'Nume',
	noAnchors: '(Nicio ancoră disponibilă în document)',
	noEmail: 'Vă rugăm să scrieţi adresa de e-mail',
	noUrl: 'Vă rugăm să scrieţi URL-ul',
	other: '<alt>',
	popupDependent: 'Dependent (Netscape)',
	popupFeatures: 'Proprietăţile ferestrei popup',
	popupFullScreen: 'Tot ecranul (Full Screen)(IE)',
	popupLeft: 'Poziţia la stânga',
	popupLocationBar: 'Bara de locaţie',
	popupMenuBar: 'Bara de meniu',
	popupResizable: 'Redimensionabil',
	popupScrollBars: 'Bare de derulare',
	popupStatusBar: 'Bara de status',
	popupToolbar: 'Bara de opţiuni',
	popupTop: 'Poziţia la dreapta',
	rel: 'Relație',
	selectAnchor: 'Selectaţi o ancoră',
	styles: 'Stil',
	tabIndex: 'Indexul tabului',
	target: 'Ţintă (Target)',
	targetFrame: '<frame>',
	targetFrameName: 'Numele frameului ţintă',
	targetPopup: '<fereastra popup>',
	targetPopupName: 'Numele ferestrei popup',
	title: 'Link (Legătură web)',
	toAnchor: 'Ancoră în această pagină',
	toEmail: 'E-Mail',
	toUrl: 'URL',
	toolbar: 'Inserează/Editează link (legătură web)',
	type: 'Tipul link-ului (al legăturii web)',
	unlink: 'Înlătură link (legătură web)',
	upload: 'Încarcă'
} );

==> ldap-account-manager_6.7.orig.tar.bz2: ldap-account-manager-6.7/templates/lib/extra/ckeditor/plugins/link/lang/ro.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'ro', {
	acccessKey: 'Tasta de acces',
	advanced: 'Avansat',
	advisoryContentType: 'Tipul consultativ al titlului',
	advisoryTitle: 'Titlul consultativ',
	anchor: {
		toolbar: 'Inserează/Editează ancoră',
		menu: 'Proprietăţi ancoră',
		title: 'Proprietăţi ancoră',
		name: 'Numele ancorei',
		errorName: 'Vă rugăm scrieţi numele ancorei',
		remove: 'Elimină ancora'
	},
	anchorId: 'după Id-ul elementului',
	anchorName: 'după numele ancorei',
	charset: 'Setul de caractere al resursei legate',
	cssClasses: 'Clasele cu stilul paginii (CSS)',
	download: 'descarcă',
	displayText: 'afișează textul',
	emailAddress: 'Adresă de e-mail',
	emailBody: 'conținut email',
	emailSubject: 'Subiectul mesajului',
	id: 'identitate',
	info: 'Informaţii despre link (Legătură web)',
	langCode: 'Direcţia cuvintelor',
	langDir: 'Direcţia cuvintelor',
	langDirLTR: 'de la stânga la dreapta (LTR)',
	langDirRTL: 'de la dreapta la stânga (RTL)',
	menu: 'Editează Link',
	name: 'Nume',
	noAnchors: 'Nu există nici o ancoră',
	noEmail: 'Vă rugăm să scrieţi adresa de e-mail',
	noUrl: 'Vă rugăm să scrieţi URL-ul',
	other: 'altceva',
	popupDependent: 'Dependent (Netscape)',
	popupFeatures: 'Proprietăţile ferestrei popup',
	popupFullScreen: 'Tot ecranul (Full Screen)(IE)',
	popupLeft: 'Poziţia la stânga',
	popupLocationBar: 'Bara de locaţie',
	popupMenuBar: 'Bara de meniu',
	popupResizable: 'Redimensionabil',
	popupScrollBars: 'Bare de derulare',
	popupStatusBar: 'Bara de stare',
	popupToolbar: 'Bara de opţiuni',
	popupTop: 'Poziţia la dreapta',
	rel: 'Relaționare',
	selectAnchor: 'Selectaţi o ancoră',
	styles: 'Stil',
	tabIndex: 'Indexul tabului',
	target: 'Ţintă (Target)',
	targetFrame: 'frame țintă',
	targetFrameName: 'Numele frameului ţintă',
	targetPopup: 'popup țintă',
	targetPopupName: 'Numele ferestrei popup',
	title: 'titlu',
	toAnchor: 'Ancoră în această pagină',
	toEmail: 'E-Mail',
	toUrl: 'URL',
	toolbar: 'Inserează/Editează link (legătură web)',
	type: 'Tipul link-ului (al legăturii web)',
	unlink: 'Înlătură link (legătură web)',
	upload: 'Încarcă'
} );
